@@ -106,7 +106,7 @@ public:
     /**
       Converts this set into an IMAP compatible sequence.
     */
-    QByteArray toImapSequence() const;
+    Q_REQUIRED_RESULT QByteArray toImapSequence() const;
 
     /**
       Return the interval corresponding to the given IMAP-compatible QByteArray representation
@@ -192,7 +192,7 @@ public:
     /**
       Returns a IMAP-compatible QByteArray representation of this set.
     */
-    QByteArray toImapSequenceSet() const;
+    Q_REQUIRED_RESULT QByteArray toImapSequenceSet() const;
 
     /**
       Return the set corresponding to the given IMAP-compatible QByteArray representation
@@ -202,12 +202,12 @@ public:
     /**
       Returns the intervals this set consists of.
     */
-    ImapInterval::List intervals() const;
+    Q_REQUIRED_RESULT ImapInterval::List intervals() const;
 
     /**
       Returns true if this set doesn't contains any values.
     */
-    bool isEmpty() const;
+    Q_REQUIRED_RESULT bool isEmpty() const;
 
     /**
      * Optimizes the ImapSet by sorting and merging overlapping intervals.
